########
numutils
########


n2w - Numbers to Words
======================

A python package to convert a number to words.

Usage
-----

::

   from numutils import n2w

   n = n2w(1023)
   n.words()

will output

::

   one thousand and twenty three

* Free software: MIT license


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
